@@ -12,7 +12,7 @@ use Plack::Util::Accessor qw(generator lang login_cb logo_image_url message_cb
 use Tags::HTML::Container;
 use Tags::HTML::Login::Access 0.10;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 sub _css {
 	my ($self, $env) = @_;
@@ -462,8 +462,9 @@ Returns Plack::Component object.
  #               Login
  #             </legend>
  #             <p>
- #               <label for="username" />
- #               User name
+ #               <label for="username">
+ #                 User name
+ #               </label>
  #               <input type="text" name="username" id="username" />
  #             </p>
  #             <p>
@@ -484,6 +485,16 @@ Returns Plack::Component object.
  #   </body>
  # </html>
 
+ # Output screenshot is in images/ directory.
+
+=begin html
+
+<a href="https://raw.githubusercontent.com/michal-josef-spacek/Plack-App-Login-Password/master/images/login_password_psgi.png">
+  <img src="https://raw.githubusercontent.com/michal-josef-spacek/Plack-App-Login-Password/master/images/login_password_psgi.png" alt="Web app example" width="300px" height="300px" />
+</a>
+
+=end html
+
 =head1 DEPENDENCIES
 
 L<Plack::Component::Tags::HTML>,
@@ -522,6 +533,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
